@@ -211,7 +211,16 @@ void PuntateMain::on_actionPuntate_Scaricate_triggered()
          USER_DIR,
          tr("Show (*.mp4)"));
     if (!fileName.isEmpty())
+        {
+        QProcess process;
+        QString program = "/opt/kmplayer/bin/kmplayer";
+        QStringList arguments;
+        arguments <<  fileName;
+
+        process.start(program, arguments);
+        if (!process.waitForFinished())
         return;
+        }
 }
 
 void PuntateMain::on_down13_2_clicked()
